Const Version = "4.12.00"
Const WCVersion = "1.06.00"
'-------------------------------------------
Const TargetApp = "ScaleTools"
'-------------------------------------------

Const FilesName = "Files.nsh"
Const DelFilesName = "DelFiles.nsh"

Const WCFilesName = "WCFiles.nsh"
Const WCDelFilesName = "WCDelFiles.nsh"

Const VersionName = "Version.nsh"

Const FilesSearchPath = "Files"

Const OwnFilesPath = "OwnFiles"

Const LanguagesPath = "Language"
Const CustomizationPath = "Customization"
Const Calib2Path = "CalibII"

MakeInstall

'-------------------------------------------------------------
'-------------------- ShowMessage ----------------------------
'-------------------------------------------------------------
Sub ShowMessage(msg, icon)

	Dim text
	text = msg
	MsgBox text, icon, "MakeInstall"

End Sub

'-------------------------------------------------------------
'-------------------- MakeInstall ----------------------------
'-------------------------------------------------------------
Sub MakeInstall

	Dim fso
	Set fso = CreateObject("Scripting.FileSystemObject")

  'Own files
  If fso.FolderExists(OwnFilesPath) Then
    fso.CopyFile OwnFilesPath + "\*", ".", true
    fso.CopyFolder OwnFilesPath + "\*", ".", true
    If fso.FileExists(FilesSearchPath + "\" + CustomizationPath + "\Instruments\CustomModels.xml") Then
      fso.DeleteFile FilesSearchPath + "\" + CustomizationPath + "\Instruments\CustomModels.xml", true
    End If
  Else
    fso.CreateFolder(OwnFilesPath)
    fso.CopyFile "installer.ico", OwnFilesPath + "\"
    fso.CopyFile "logo_150x57.bmp", OwnFilesPath + "\"
    
    fso.CreateFolder(OwnFilesPath + "\" + FilesSearchPath)

    fso.CopyFolder FilesSearchPath + "\" + CustomizationPath, OwnFilesPath + "\" + FilesSearchPath + "\"
    fso.CopyFolder FilesSearchPath + "\" + Calib2Path, OwnFilesPath + "\" + FilesSearchPath + "\"
    
    fso.CopyFile FilesSearchPath + "\app_shortcut.ico", OwnFilesPath + "\" + FilesSearchPath + "\"
    fso.CopyFile FilesSearchPath + "\weighconsole_shortcut.ico", OwnFilesPath + "\" + FilesSearchPath + "\"
  End If

	Dim target_tool
	target_tool = TargetApp + "_" + Version + ".exe"
	If fso.FileExists(target_tool) Then
		fso.DeleteFile(target_tool)
	End If

	'VersionName
	If fso.FileExists(VersionName) Then
		fso.DeleteFile(VersionName)
	End If
	Dim file_version
	Set file_version = fso.CreateTextFile(VersionName, True)
	file_version.WriteLine "!define VERSION """ + Version + """"
	file_version.WriteLine "!define WCVERSION """ + WCVersion + """"
	file_version.Close

	'creazione Files.nsh con i file da includere nell'installazione
	If fso.FileExists(FilesName) Then
		fso.DeleteFile(FilesName)
	End If

	If fso.FileExists(WCFilesName) Then
		fso.DeleteFile(WCFilesName)
	End If

	Dim file_instfiles
	Set file_instfiles = fso.CreateTextFile(FilesName, True)
	
	Dim wconsole_instfiles
	Set wconsole_instfiles = fso.CreateTextFile(WCFilesName, True)

	'creazione DelFiles.nsh con i file da cancellare durante la disinstallazione
	If fso.FileExists(DelFilesName) Then
		fso.DeleteFile(DelFilesName)
	End If

	If fso.FileExists(WCDelFilesName) Then
		fso.DeleteFile(WCDelFilesName)
	End If

	Dim file_delfiles
	Set file_delfiles = fso.CreateTextFile(DelFilesName, True)
	
	Dim wconsole_delfiles
	Set wconsole_delfiles = fso.CreateTextFile(WCDelFilesName, True)

	Dim folder
	Set folder = fso.GetFolder(FilesSearchPath)
	
	Dim folder_files
	Set folder_files = folder.Files

	file_instfiles.WriteLine ";================== File inclusi nell'installazione =================="
	file_instfiles.WriteLine ""

	file_delfiles.WriteLine ";================== File da eliminare durante la disinstallazione =================="
	file_delfiles.WriteLine ""

	Dim filename

  For Each filename In folder_files
    If InStr(1, LCase(filename), "weighconsole", vbTextCompare) = 0 Then
      file_instfiles.WriteLine "File """ + filename + """"
      file_delfiles.WriteLine "Delete ""$INSTDIR\" + filename.Name + """"
      
      If LCase(Right(filename, 3)) = "dll" Then
        wconsole_instfiles.WriteLine "File """ + filename + """"
        wconsole_delfiles.WriteLine "Delete ""$INSTDIR\" + filename.Name + """"
      End If
    Else
      wconsole_instfiles.WriteLine "File """ + filename + """"
      wconsole_delfiles.WriteLine "Delete ""$INSTDIR\" + filename.Name + """"
    End If
  Next
  
  'subdirectories
	Dim root_folders
	Set root_folders = folder.SubFolders

	Dim root_folder
	for each root_folder in root_folders
		'ShowMessage "Cartella: '" + root_folder.Path + "'", vbInformation
		AddFolder root_folder.Name, root_folder.Path, file_instfiles, file_delfiles
    
    If root_folder.Name = LanguagesPath Or root_folder.Name = CustomizationPath Then
      AddFolder root_folder.Name, root_folder.Path, wconsole_instfiles, wconsole_delfiles
    End If
	next
  
	file_instfiles.Close
	file_delfiles.Close
	
	wconsole_instfiles.Close
	wconsole_delfiles.Close
  
	Dim WshShell
	Set WshShell = CreateObject("WScript.Shell")
	Dim Nsis
  Nsis = "NSIS\makensis.exe"
  
	WshShell.Run Nsis + " /V4 /OLogScaleTools.txt ScaleTools.nsi", 1, true

	'Delete created files
	If fso.FileExists(FilesName) Then
		fso.DeleteFile(FilesName)
	End If

	If fso.FileExists(DelFilesName) Then
		fso.DeleteFile(DelFilesName)
	End If

	If fso.FileExists(WCFilesName) Then
		fso.DeleteFile(WCFilesName)
	End If

	If fso.FileExists(WCDelFilesName) Then
		fso.DeleteFile(WCDelFilesName)
	End If

	If fso.FileExists(VersionName) Then
		fso.DeleteFile(VersionName)
	End If

	If fso.FileExists(target_tool) Then
		ShowMessage "Created the file '" + target_tool + "'", vbInformation
	Else
    ShowMessage "Error while creating the file '" + target_tool + "'" + vbCRLf + "Look at LogScaleTools.txt", vbCritical
	End If
End Sub

'-------------------------------------------------------------
'------------------------- AddFolder -------------------------
'-------------------------------------------------------------
Sub AddFolder(folder_name, folder_path, file_instfiles, file_delfiles)
  Dim fso
	Set fso = CreateObject("Scripting.FileSystemObject")

	Dim folder
	Set folder = fso.GetFolder(folder_path)
	
	Dim folder_files
	Set folder_files = folder.Files

  Dim filename
  
  For Each filename In folder_files
		file_instfiles.WriteLine "File ""/oname=" + "$INSTDIR\" + folder_name + "\" + filename.Name + """ """ + filename + """"
		file_delfiles.WriteLine "Delete """ + "$INSTDIR\" + folder_name + "\" + filename.Name + """"
  Next

  'subdirectories
	Dim root_folders
	Set root_folders = folder.SubFolders

	Dim root_folder
	for each root_folder in root_folders
		'ShowMessage "Cartella: '" + root_folder.Path + "'", vbInformation
    file_instfiles.WriteLine "CreateDirectory """ + "$INSTDIR\" + folder_name + "\" + root_folder.Name + """"
		AddFolder folder_name + "\" + root_folder.Name, root_folder.Path, file_instfiles, file_delfiles
    file_delfiles.WriteLine "RMDir """ + "$INSTDIR\" + folder_name + "\" + root_folder.Name + """"
	next
End Sub
