;NSIS Modern User Interface
;Multilingual Example Script
;Written by Joost Verburg

;To add values
!define __APPLICATION_NAME__ ScaleTools
!define __APPLICATION_FILENAME__  ScaleTools                ;file .exe of the application
!define __COMPANY_NAME__ Load Cell Central
!define __INSTALL_ICON__          installer.ico             ;icon of the installer file
!define __INSTALL_LOGO__          logo_150x57.bmp           ;logo displayed by the installer
!define __APPLICATION_ICON__      app_shortcut.ico          ;application icon for shortcuts (Start menu and desktop)
!define __COMPANY_WWW__ www.800loadcel.com
!define __WC_ICON__               weighconsole_shortcut.ico ;WeighConsole icon for shortcuts (Start menu, desktop and quick launch

;--------------------------------
;Include Modern UI

  !include "MUI.nsh"
	!include "Sections.nsh"

;--------------------------------
;Variables
	Var STInstalled

;--------------------------------
;General

	!define MULTIUSER_EXECUTIONLEVEL Admin
	!include MultiUser.nsh

  ;<<<---
  !define APPLICATION "${__APPLICATION_NAME__}"

  !define MULTIUSER_INIT_TEXT_ADMINREQUIRED "${APPLICATION} requires administrator priviledges. Right click on the application icon and click on 'Run as administrator'."

  ;<<<---
  !define REGKEY "Dini Argeo srl\DINITOOLS"
	
	!include "Version.nsh"

  ;Name and file
  Name "${APPLICATION}"
  
  OutFile "${APPLICATION}_${VERSION}.exe"
  
  ;Default installation folder
  InstallDir "$PROGRAMFILES\${APPLICATION}"
  
	RequestExecutionLevel user

;--------------------------------
;Interface Settings

  !define MUI_ABORTWARNING

  ;<<<---
  !define MUI_ICON ${__INSTALL_ICON__}
    
  !define MUI_UNICON uninstall.ico

  ;<<<---
  !define MUI_HEADERIMAGE
    !define MUI_HEADERIMAGE_BITMAP ${__INSTALL_LOGO__} ;logo_150x57.bmp

;--------------------------------
;Language Selection Dialog Settings

  ;Remember the installer language
  !define MUI_LANGDLL_REGISTRY_ROOT "HKLM" 
  !define MUI_LANGDLL_REGISTRY_KEY "Software\${REGKEY}" 
  !define MUI_LANGDLL_REGISTRY_VALUENAME "Installer Language"

;--------------------------------
;Pages

  !insertmacro MUI_PAGE_LICENSE "Warranty.rtf"
	
  !insertmacro MUI_PAGE_DIRECTORY
	!insertmacro MUI_PAGE_COMPONENTS
  !insertmacro MUI_PAGE_INSTFILES
  
  !insertmacro MUI_UNPAGE_CONFIRM
  !insertmacro MUI_UNPAGE_INSTFILES

;--------------------------------
;Languages

  !insertmacro MUI_LANGUAGE "English" ;first language is the default language
  !insertmacro MUI_LANGUAGE "French"
  !insertmacro MUI_LANGUAGE "German"
  !insertmacro MUI_LANGUAGE "Spanish"
  !insertmacro MUI_LANGUAGE "Italian"
  !insertmacro MUI_LANGUAGE "Dutch"

;--------------------------------
;Reserve Files
  
  ;If you are using solid compression, files that are required before
  ;the actual installation should be stored first in the data block,
  ;because this will make your installer start faster.
  
  !insertmacro MUI_RESERVEFILE_LANGDLL

;--------------------------------
;Installer Sections

;<<<---
Section "${__APPLICATION_NAME__}" SecScaleTools
  SetOutPath "$INSTDIR"
  
  CreateDirectory "$INSTDIR\Temp"
  CreateDirectory "$INSTDIR\Diz"
  CreateDirectory "$INSTDIR\Firmwares"
  CreateDirectory "$INSTDIR\Setups"
  CreateDirectory "$INSTDIR\SQL"
  CreateDirectory "$INSTDIR\Printer"
  CreateDirectory "$INSTDIR\Printer\Fonts"
  CreateDirectory "$INSTDIR\Language"
  CreateDirectory "$INSTDIR\Instruments"
  CreateDirectory "$INSTDIR\CalibII"
  
  CreateDirectory "$INSTDIR\Customization"

  ;ADD YOUR OWN FILES HERE...
  !include "Files.nsh"
  
  ;Store installation folder
  WriteRegStr HKLM "Software\${REGKEY}" "" "$INSTDIR\"
  
  ;Store application version
  WriteRegStr HKLM "Software\${REGKEY}" "Version" ${VERSION}

  ;<<<---
  ;Chiavi di registro per disinstallazione (inserimento applicazioni nel pannello di controllo / Installazione applicazioni)
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${__APPLICATION_NAME__}" "DisplayName" "${__APPLICATION_NAME__}"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${__APPLICATION_NAME__}" "DisplayIcon" "$INSTDIR\${__APPLICATION_ICON__}"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${__APPLICATION_NAME__}" "UninstallString"  "$INSTDIR\Uninstall.exe"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${__APPLICATION_NAME__}" "URLInfoAbout" "${__COMPANY_WWW__}"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${__APPLICATION_NAME__}" "URLUpdateInfo" "${__COMPANY_WWW__}"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${__APPLICATION_NAME__}" "Publisher" "${__APPLICATION_NAME__}"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${__APPLICATION_NAME__}" "DisplayVersion" ${VERSION}
  WriteRegDWORD HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${__APPLICATION_NAME__}" "NoModify" 0x00000001
  WriteRegDWORD HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${__APPLICATION_NAME__}" "NoRepair" 0x00000001
	
  ;Create uninstaller
  WriteUninstaller "$INSTDIR\Uninstall.exe"
  
  ;Create shorcuts
  ;Start shortcut
  CreateDirectory "$SMPROGRAMS\${APPLICATION}"

  ;<<<---
  CreateShortCut "$SMPROGRAMS\${APPLICATION}\${APPLICATION}.lnk" "$INSTDIR\${__APPLICATION_FILENAME__}.exe" "" "$INSTDIR\${__APPLICATION_ICON__}" 0
  
  CreateShortCut "$SMPROGRAMS\${APPLICATION}\Uninstall.lnk" "$INSTDIR\Uninstall.exe"

  ;Desktop shortcut
  ;<<<---
  CreateShortCut "$DESKTOP\${APPLICATION}.lnk" "$INSTDIR\${__APPLICATION_FILENAME__}.exe" "" "$INSTDIR\${__APPLICATION_ICON__}" 0

	;Set "Run as administrator" flag
  ;<<<---
	WriteRegStr HKLM "Software\Microsoft\Windows NT\CurrentVersion\AppCompatFlags\layers" "$INSTDIR\${__APPLICATION_FILENAME__}.exe" "RUNASADMIN"
  
  ;Quick launch shortcut
  ;CreateShortCut "$QUICKLAUNCH\WeighConsole.lnk" "$INSTDIR\WeighConsole.exe"

	;ScaleTools installed
	StrCpy $STInstalled "1"
SectionEnd

Section "WeighConsole" SecWeighConsole
  SetOutPath "$INSTDIR"

  CreateDirectory "$INSTDIR\Language"
  CreateDirectory "$INSTDIR\Customization"

  ;Create shorcuts
  ;Start shortcut
  CreateDirectory "$SMPROGRAMS\${APPLICATION}"

  ;ADD YOUR OWN FILES HERE...
  !include "WCFiles.nsh"

	CreateShortCut "$SMPROGRAMS\${APPLICATION}\WeighConsole.lnk" "$INSTDIR\WeighConsole.exe" "" "$INSTDIR\${__WC_ICON__}" 0

  ;Desktop shortcut
  CreateShortCut "$DESKTOP\WeighConsole.lnk" "$INSTDIR\WeighConsole.exe" "" "$INSTDIR\${__WC_ICON__}" 0

  ;Quick launch shortcut
  CreateShortCut "$QUICKLAUNCH\WeighConsole.lnk" "$INSTDIR\WeighConsole.exe" "" "$INSTDIR\${__WC_ICON__}" 0

  ;Create uninstaller
  WriteUninstaller "$INSTDIR\Uninstall.exe"

  CreateShortCut "$SMPROGRAMS\${APPLICATION}\Uninstall.lnk" "$INSTDIR\Uninstall.exe"
	
	StrCmp $STInstalled "0" 0 NoWCUninstall
  ;<<<---
  ReadRegStr $5 HKLM Software\Microsoft\Windows\CurrentVersion\Uninstall\${__APPLICATION_NAME__} "DisplayName"
  StrCmp $5 "DiniTools" NoWCUninstall 0
  ;Chiavi di registro per disinstallazione (inserimento applicazioni nel pannello di controllo / Installazione applicazioni)
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${__APPLICATION_NAME__}" "DisplayName" "WeighConsole"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${__APPLICATION_NAME__}" "DisplayIcon" "$INSTDIR\${__WC_ICON__}"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${__APPLICATION_NAME__}" "UninstallString"  "$INSTDIR\Uninstall.exe"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${__APPLICATION_NAME__}" "URLInfoAbout" "${__COMPANY_WWW__}"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${__APPLICATION_NAME__}" "URLUpdateInfo" "${__COMPANY_WWW__}"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${__APPLICATION_NAME__}" "Publisher" "${__COMPANY_NAME__}"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${__APPLICATION_NAME__}" "DisplayVersion" ${WCVERSION}
  WriteRegDWORD HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${__APPLICATION_NAME__}" "NoModify" 0x00000001
  WriteRegDWORD HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${__APPLICATION_NAME__}" "NoRepair" 0x00000001

NoWCUninstall:
SectionEnd

;--------------------------------
;Installer Functions

Function .onInit
	;check for requested rights
	!insertmacro MULTIUSER_INIT

  !insertmacro MUI_LANGDLL_DISPLAY

	Call CheckInstall
;	Call InitComponents

	StrCpy $STInstalled "0"
FunctionEnd

;--------------------------------
;Texts

	LangString TXT_SCALETOOLS ${LANG_ENGLISH} "Tool for scales configuration"
	LangString TXT_SCALETOOLS ${LANG_FRENCH} "Application pour la configuration des balances"
	LangString TXT_SCALETOOLS ${LANG_GERMAN} "Anwendung fr die Konfiguration der Waagen"
	LangString TXT_SCALETOOLS ${LANG_SPANISH} "Aplicacin para la configuracin de las balanzas"
	LangString TXT_SCALETOOLS ${LANG_ITALIAN} "Applicazione per la configurazione delle bilance"
	LangString TXT_SCALETOOLS ${LANG_DUTCH} "Tools voor configuratie weegschalen"
	
	LangString TXT_WEIGHCONSOLE ${LANG_ENGLISH} "It allows to insert in a very simple way the connected scale weight in documents, Exel files, etc."
	LangString TXT_WEIGHCONSOLE ${LANG_FRENCH} "Permet dinsrer facilement le poids de la balance connexe dans des documents, fichier dExcel, et ctera"
	LangString TXT_WEIGHCONSOLE ${LANG_GERMAN} "Erlaubt das Gewicht der angeschlossenen Waage leicht in Dokumente, ExcelDateien usw. einzufgen"
	LangString TXT_WEIGHCONSOLE ${LANG_SPANISH} "Permite de inserir fcilmente el peso de la balanza conectada en documentos, ficheros Excel, etc."
	LangString TXT_WEIGHCONSOLE ${LANG_ITALIAN} "Consente di inserire facilmente il peso della bilancia collegata in documenti, file di Excel, ecc."
	LangString TXT_WEIGHCONSOLE ${LANG_DUTCH} "Maakt het mogelijk het gewicht van de aangesloten weegschaal in documenten, Excelbestanden enz. in te voegen."
;--------------------------------
;Descriptions

  ;USE A LANGUAGE STRING IF YOU WANT YOUR DESCRIPTIONS TO BE LANGAUGE SPECIFIC

  ;Assign descriptions to sections
  !insertmacro MUI_FUNCTION_DESCRIPTION_BEGIN
		!insertmacro MUI_DESCRIPTION_TEXT ${SecScaleTools} $(TXT_SCALETOOLS)
        !insertmacro MUI_DESCRIPTION_TEXT ${SecWeighConsole} $(TXT_WEIGHCONSOLE)
        
  !insertmacro MUI_FUNCTION_DESCRIPTION_END

;--------------------------------
;Uninstaller Section

Section "Uninstall"

  ;ADD YOUR OWN FILES HERE...
  
  ;Delete shorcuts
  ;Start shortcut
  Delete "$SMPROGRAMS\${APPLICATION}\${APPLICATION}.lnk"
  Delete "$SMPROGRAMS\${APPLICATION}\WeighConsole.lnk"
  ;Delete "$SMPROGRAMS\${APPLICATION}\Calibration Tool.lnk"
  ;Delete "$SMPROGRAMS\${APPLICATION}\PCX2ITA.lnk"
  Delete "$SMPROGRAMS\${APPLICATION}\Uninstall.lnk"
  RMDir "$SMPROGRAMS\${APPLICATION}"

  ;Desktop shortcut
  Delete "$DESKTOP\${APPLICATION}.lnk"
	Delete "$DESKTOP\WeighConsole.lnk"
  
  ;Quick launch shortcut
  Delete "$QUICKLAUNCH\WeighConsole.lnk"

  !include "DelFiles.nsh"
  !include "WCDelFiles.nsh"

  Delete "$INSTDIR\Uninstall.exe"

  RMDir "$INSTDIR\Temp"
  RMDir "$INSTDIR\Diz"
  RMDir "$INSTDIR\Firmwares"
  RMDir "$INSTDIR\Setups"
  RMDir "$INSTDIR\SQL"
  RMDir "$INSTDIR\Printer\Fonts"
  RMDir "$INSTDIR\Printer"
  RMDir "$INSTDIR\Language"
  RMDir "$INSTDIR\Instruments"
  RMDir "$INSTDIR\CalibII"

  ;Delete "$INSTDIR\Link.ico"
  Delete "$INSTDIR\Customization\*.*"
  RMDir "$INSTDIR\Customization"

  ;Se ci sono file creati dopo l'esecuzione la directory rimarr
  RMDir "$INSTDIR"

	;Cancellazioni chiavi di registro con percorso di installazione
	;e lingua di istallazione
  DeleteRegKey HKLM "Software\${REGKEY}"

  ;<<<---
	;Cancellazioni chiavi di registro per disinstallazione
  DeleteRegKey HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${__APPLICATION_NAME__}"
	
	;Cancellazione chiave di registro per flag "Run as administrator"
	DeleteRegValue HKLM "Software\Microsoft\Windows NT\CurrentVersion\AppCompatFlags\layers" "$INSTDIR\${__APPLICATION_FILENAME__}.exe"
SectionEnd

;--------------------------------
;Uninstaller Functions

Function un.onInit
	!insertmacro MULTIUSER_UNINIT

  !insertmacro MUI_UNGETLANGUAGE
  
FunctionEnd
;--------------------------------
;--------------------------------

;--------------------------------
;Controlla se l'installazione  possibile, se non
;lo  la abortisce
Function CheckInstall
	;c' net framework?
  IfFileExists "$WINDIR\Microsoft.NET\Framework\v2.0.50727\installUtil.exe" OkNetFramework
		StrCmp $LANGUAGE ${LANG_ITALIAN} 0 EnglishMsg
			MessageBox MB_OK|MB_ICONSTOP "Net Framework non presente nel sistema.$\r$\nSenza il framework l'applicazione non pu funzionare"
			Goto WarningShown
EnglishMsg:
			MessageBox MB_OK|MB_ICONSTOP "The Net Framework has not been detected.$\r$\nWithout this framework the application can not work."

WarningShown:
	StrCmp $LANGUAGE ${LANG_ITALIAN} 0 EnglishMsg2
		MessageBox MB_YESNO|MB_ICONQUESTION "Si vuole scaricare ed installare il framework ora?" IDYES DownloadNet IDNO QuitCheck
EnglishMsg2:
  	MessageBox MB_YESNO|MB_ICONQUESTION "Download and install the framework right now?" IDYES DownloadNet IDNO QuitCheck

DownloadNet:
  ExecShell Open "http://www.microsoft.com/downloads/info.aspx?na=90&p=&SrcDisplayLang=en&SrcCategoryId=&SrcFamilyId=0856eacb-4362-4b0d-8edd-aab15c5e04f5&u=http%3a%2f%2fdownload.microsoft.com%2fdownload%2f5%2f6%2f7%2f567758a3-759e-473e-bf8f-52154438565a%2fdotnetfx.exe" SW_SHOWNORMAL

QuitCheck:
  Quit

OkNetFramework:

  ;l'applicazione  gi installata?
  ; ReadRegStr $0 HKLM "Software\${REGKEY}" ""
  ; StrCpy $1 ""
  ; StrCmp $0 $1 NotInstalled 0
		; StrCmp $LANGUAGE ${LANG_ITALIAN} 0 EnglishMsg3
			; MessageBox MB_YESNO|MB_ICONQUESTION "Applicazione gi presente nel sistema.$\r$\nSi consiglia di disinstallarla e poi procedere con l'installazione di questa versione.$\r$\nProcedere comunque con linstallazione?" IDYES NotInstalled IDNO AbortInstall
; EnglishMsg3:
			; MessageBox MB_YESNO|MB_ICONQUESTION "Application already installed.$\r$\nIt is recommended to uninstall it and then install this version.$\r$\nContinue installation?" IDYES NotInstalled IDNO AbortInstall

; AbortInstall:
	; Quit

;NotInstalled:
FunctionEnd

;--------------------------------
; IsDotNETInstalled
;
; Based on GetDotNETVersion
;   http://nsis.sourceforge.net/Get_.NET_Version
;
; Usage:
;   Call IsDotNETInstalled
;   Pop $0
;   StrCmp $0 1 found.NETFramework no.NETFramework
;Function IsDotNETInstalled
;   Push $0
;   Push $1
;
;   StrCpy $0 1
;   System::Call "mscoree::GetCORVersion(w, i ${NSIS_MAX_STRLEN}, *i) i .r1"
;   StrCmp $1 0 +2
;     StrCpy $0 0
;
;   Pop $1
;   Exch $0
;FunctionEnd
